// (c) Thomas Kamps, 2009
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the7 implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

#ifndef CAPITALISM_H
#define CAPITALISM_H

#include <QtGui/QMainWindow>
#include <QTableWidget>
#include <QStackedLayout>
#include <QList>
#include "src/Monopd/monopdgame.h"
#include "src/Monopd/monopdclient.h"
#include "src/Monopd/monopdfield.h"
#include "gameconfig.h"
#include "field.h"
#include "trade.h"
#include "config.h"

namespace Ui {
	class Capitalism;
}

class Capitalism : public QMainWindow {
	Q_OBJECT

	public:
		Capitalism(QTcpSocket* sok, QWidget *parent = 0);
		~Capitalism();

		QStackedLayout* layout;
		QTableWidget* games;
		GameConfig* gameConfig;
		Field* field;

		MonopdGame* getGame();

		void setClient(MonopdClient* c);
		void setGame(MonopdGame* g);

	private:
		Ui::Capitalism *ui;
		MonopdClient* client;
		Config* config;
		MonopdGame* game;
		QList<Trade*> trades;

		int selectedField;

		bool firstShow;
		bool chatVisible;
		bool eventVisible;
		bool chatColor;
		bool eventColor;

		void newGames();
		void newGameConfig();
		void newField();

		Trade* getTrade(int tid);
		void removeTrade(Trade* t);

	public slots:
		void send(QString msg);

	private slots:
		void drawField();
		void addToList(Player* p);
		void showChat(int pid, QString msg);
		void showEvent(QString type, QString msg);
		void setCurGame();
		void setOptionsEnabled(int gid, int newMaster);
		void startGame(int r, int c);
		void roll();
		void buy();
		void jailRoll();
		void jailCard();
		void jailPay();

		void sendMsg();

		void setSelectedField(MonopdField* f);
		void updateEstateDock();
		void playerUpdate();
		void updateGameList();
		void normalChatTitle(bool vis);
		void normalEventTitle(bool vis);

		void tradeUpdate(QString type, int tradeId, int actor, int rev);
		void tradePlayerUpdate(int tradeId, int playerid, bool accept);
		void tradeEstateUpdate(int tradeId, int estateId, int targetPlayerId);
		void tradeCardUpdate(int tradeId, int cardId, int targetPlayerId);
		void tradeMoneyUpdate(int tradeId, int fromPlayerId, int money, int targetPlayerId);

		void leaveGame();
		void disconnectFromServer();
		void exit();

	protected:
		void closeEvent(QCloseEvent* event);
		void showEvent(QShowEvent* event);
};

#endif // CAPITALISM_H
