// (c) Thomas Kamps, 2009
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the7 implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

#include <QSettings>
#include "config.h"
#include "ui_config.h"

Config::Config(QWidget *parent) : QDialog(parent), m_ui(new Ui::Config) {
	m_ui->setupUi(this);

	m_ui->cbImage->addItem(QIcon(":/Icons/Avatars/badge.png"),         "", QVariant("badge.png"));
	m_ui->cbImage->addItem(QIcon(":/Icons/Avatars/beachball.png"),     "", QVariant("beachball.png"));
	m_ui->cbImage->addItem(QIcon(":/Icons/Avatars/bell.png"),          "", QVariant("bell.png"));
	m_ui->cbImage->addItem(QIcon(":/Icons/Avatars/bomb.png"),          "", QVariant("bomb.png"));
	m_ui->cbImage->addItem(QIcon(":/Icons/Avatars/cat.png"),           "", QVariant("cat.png"));
	m_ui->cbImage->addItem(QIcon(":/Icons/Avatars/cookie.png"),        "", QVariant("cookie.png"));
	m_ui->cbImage->addItem(QIcon(":/Icons/Avatars/cube.png"),          "", QVariant("cube.png"));
	m_ui->cbImage->addItem(QIcon(":/Icons/Avatars/eyeball.png"),       "", QVariant("eyeball.png"));
	m_ui->cbImage->addItem(QIcon(":/Icons/Avatars/flag.png"),          "", QVariant("flag.png"));
	m_ui->cbImage->addItem(QIcon(":/Icons/Avatars/ghost.png"),         "", QVariant("ghost.png"));
	m_ui->cbImage->addItem(QIcon(":/Icons/Avatars/globe.png"),         "", QVariant("globe.png"));
	m_ui->cbImage->addItem(QIcon(":/Icons/Avatars/hamburger.png"),     "", QVariant("hamburger.png"));
	m_ui->cbImage->addItem(QIcon(":/Icons/Avatars/lips.png"),          "", QVariant("lips.png"));
	m_ui->cbImage->addItem(QIcon(":/Icons/Avatars/puzzle.png"),        "", QVariant("puzzle.png"));
	m_ui->cbImage->addItem(QIcon(":/Icons/Avatars/pyramid.png"),       "", QVariant("pyramid.png"));
	m_ui->cbImage->addItem(QIcon(":/Icons/Avatars/skull.png"),         "", QVariant("skull.png"));
	m_ui->cbImage->addItem(QIcon(":/Icons/Avatars/traffic_light.png"), "", QVariant("traffic_light.png"));
	m_ui->cbImage->addItem(QIcon(":/Icons/Avatars/wizard.png"),        "", QVariant("wizard.png"));
	QSettings s;

	QString image = s.value("player/image", "bell.png").toString();
	int i = m_ui->cbImage->findData(QVariant(image));
	if (i < 0) i = 0;
	m_ui->cbImage->setCurrentIndex(i);
	m_ui->cbImage->setIconSize(QSize(32,32));

	QString name = s.value("player/name", "Capitalism").toString();
	m_ui->tfName->setText(name);

	connect(m_ui->buttonBox, SIGNAL(accepted()), this, SLOT(save()));
}

Config::~Config() {
	delete m_ui;
}

void Config::save() {
	QSettings s;

	QString oldName = s.value("player/name", "Capitalism").toString();
	QString newName = m_ui->tfName->text();
	s.setValue("player/name", newName);

	int i = m_ui->cbImage->currentIndex();
	QString image = m_ui->cbImage->itemData(i).toString();
	s.setValue("player/image", image);

	if (newName != oldName)
	emit(saved(".n"+newName));

	emit(saved(".pi"+image));
}

void Config::changeEvent(QEvent *e) {
	QDialog::changeEvent(e);

	switch (e->type()) {
		case QEvent::LanguageChange:
			m_ui->retranslateUi(this);
			break;
		default:
			break;
	}
}
